==> 0.0.5.tar.gz: lib/features/presntation/widget/sent_message_widget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:itg_chat/features/data/repository/chat_repo_implemnt.dart';
import 'package:itg_chat/features/domain/use_cases/create_group_withMessage.dart';
import 'package:itg_chat/features/presntation/bloc/showmessagedetails/showmessagedetails_cubit.dart';
import 'package:rxdart/rxdart.dart';

class SentMessageMessageWidget extends StatelessWidget{
   final BehaviorSubject<String> image;
   final BehaviorSubject<TextEditingController> message ;
   final BehaviorSubject<int> LoggedInUserProfileId;
   final BehaviorSubject<int> OtherUserProfileId;
   final BehaviorSubject<String> Header;
  const SentMessageMessageWidget({
    Key key,
     this.message,  this.image, this.LoggedInUserProfileId, this.OtherUserProfileId, this.Header
  }) : super(key: key);
   @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Row(
      children: [
        IconButton(icon: Icon(Icons.camera_alt_rounded),
            color: Colors.blue,
            onPressed: () {

            }),
        IconButton(icon: Icon(Icons.keyboard_voice),
            color: Colors.blue,
            onPressed: () {}),
        Container(
            height: 100,
            width: 230,
            child: TextField(decoration: InputDecoration(
                labelText: 'Type a message...'),
              controller: message.value,
            )),
        IconButton(icon: Icon(Icons.send),
            color: Colors.blue,
            onPressed: () async {
              if (message.value.text.isNotEmpty)
                await createGroupWithMessage(GetIt.instance<CahtRepoImplemtion>()).call(
                    LoggedInUserProfileId.value, OtherUserProfileId.value,
                    message.value.text,
                    OtherUserProfileId.value,
                    1,
                    1,
                    Header.value);
              else{
                print("");}
              message.value.clear();
              BlocProvider.of<ShowChatDetailsCubit>(context)
                  .showdetailsmessage(
                  LoggedInUserProfileId.value, OtherUserProfileId.value, Header.value);
            })
      ],
    );
  }
}

==> 0.0.8.tar.gz: lib/features/presntation/widget/sent_message_widget.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:get_it/get_it.dart';
import 'package:itg_chat/features/data/repository/chat_repo_implemnt.dart';
import 'package:itg_chat/features/domain/use_cases/create_group_withMessage.dart';
import 'package:itg_chat/features/presntation/bloc/showmessagedetails/showmessagedetails_cubit.dart';
import 'package:rxdart/rxdart.dart';

class SentMessageMessageWidget extends StatelessWidget{
   final BehaviorSubject<String> image;
   final TextEditingController message ;
   final int LoggedInUserProfileId;
   final int OtherUserProfileId;
   final String Header;
  const SentMessageMessageWidget({
    Key key,
     this.message,  this.image, this.LoggedInUserProfileId, this.OtherUserProfileId, this.Header
  }) : super(key: key);
   @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Row(
      children: [
        IconButton(icon: Icon(Icons.camera_alt_rounded),
            color: Colors.blue,
            onPressed: () {

            }),
        IconButton(icon: Icon(Icons.keyboard_voice),
            color: Colors.blue,
            onPressed: () {}),
        Container(
            height: 100,
            width: 230,
            child: TextField(decoration: InputDecoration(
                labelText: 'Type a message...'),
              controller: message,
            )),
        IconButton(icon: Icon(Icons.send),
            color: Colors.blue,
            onPressed: () async {
              if (message.value.text.isNotEmpty)
                await createGroupWithMessage(GetIt.instance<CahtRepoImplemtion>()).call(
                    LoggedInUserProfileId, OtherUserProfileId,
                    message.value.text,
                    OtherUserProfileId,
                    1,
                    1,
                    await Header);
              else{
                print("");}
              message.clear();
              BlocProvider.of<ShowChatDetailsCubit>(context)
                  .showdetailsmessage(
                  LoggedInUserProfileId, OtherUserProfileId, Header);
            })
      ],
    );
  }
}
